import moment from "moment";
import amountUtils from "@/index/utils/amountUtils";
import { timestamp2Quarter } from "@/index/utils/time";
import constants from "@/index/utils/constants";

const { sumRecordID, nullValueArr } = constants
const { numMulti, numAdd } = amountUtils;

export function defaultRender(text, row, index) {
  if (row.id === sumRecordID) {
    return text;
  } else if (nullValueArr.includes(text)) {
    return "--";
  } else {
    return text;
  }
}

export function outsourcingCostRender(text, row, index) {
  if (row.id === sumRecordID) {
    return text;
  } else if (nullValueArr.includes(text)) {
    return "--";
  } else {
    return text;
  }
}

export function quarterRender(text, row, index) {
  if (row.id === sumRecordID) {
    return `合计(${index})`;
  } else if (nullValueArr.includes(text)) {
    return "--";
  } else {
    return timestamp2Quarter(text);
  }
}

export function dateRender(text, row, index) {
  if (row.id === sumRecordID) {
    return "";
  } else if (nullValueArr.includes(text)) {
    return "--";
  }else{
    return moment(parseInt(text)).format("YYYY-MM-DD");
  }
}

export function timeRender(text, row, index){
  if (row.id === sumRecordID) {
    return "";
  } else if (nullValueArr.includes(text)) {
    return "--";
  }else{
    return moment(parseInt(text)).format("YYYY-MM-DD HH:MM:SS");
  }
}

export function scheduleRender(text, row, index) {
  if (row.id === sumRecordID) {
    return "";
  }else {
    const begin = nullValueArr.includes(row.begin)? "--" : moment(parseInt(row.begin)).format("YYYY-MM-DD");
    const due = nullValueArr.includes(row.begin) ? "--" : moment(parseInt(row.due)).format("YYYY-MM-DD");
    return begin + " 至 " + due;
  }
}

export function enlargedScaleRenderFun(enlargedScale) {
  return (text, row, index) => {
    if(enlargedScale===1){
      return `${numAdd(row.inSize, row.outSize)}(${row.inSize}/${row.outSize})`;
    }else{
      const inSize = numMulti(row.inSize, enlargedScale);
      const outSize = numMulti(row.outSize, enlargedScale);
      return `${numAdd(inSize, outSize)}(${inSize}/${outSize})`;
    }
  }
}

export function enlargedScaleOnlySumRenderFun(enlargedScale) {
  return (text, row, index) => {
    const inSize = numMulti(row.inSize, enlargedScale);
    const outSize = numMulti(row.outSize, enlargedScale);
    return `${numAdd(inSize, outSize)}`;
  }
}

export function serialNumberRender(text, row, index) {
  if (row.id === sumRecordID) {
    return `合计(${index})`;
  }else{
    return index + 1;
  }
}

export function enlargedRenderFun(enlargedScale){
  return (text, row, index) => {
      if(enlargedScale===1){
        return nullValueArr.includes(text)? "--" : text;
      }
      return numMulti(enlargedScale, text);
  }
}


